
	#define BANKVARS 0x0c
	RADIX dec
	LIST P=18F46J50, F=INHX32		;directive to define processor
	#include <P18F46J50.INC>		;processor specific variable definitions

	global	PixosInit,NewLine

	extern  RowCtr2,DimValue;
	extern	SCREENMEM
	extern	v1,v2,v3,v4
	extern	sFSR0L,sFSR0H,Int2FSR0L,Int2FSR0H
	extern	t1,t2,t3,t4,t5,t6,t7,t8


	#define	LATCH			TRISD, 0
	#define	SCLK			TRISD, 1
	#define	BLANK			TRISD, 2		; Low Side Control
	#define	CSEL0			TRISD, 3
	#define	CSEL1			TRISD, 4
	#define CSEL2			TRISD, 5
	#define	SIN				TRISD, 6
	#define	DSEL			TRISD, 7

	#define	SCLK1			PORTB, 4
	#define	SDAT1			PORTB, 5
	#define	SCLK1_DIR		TRISB, 4
	#define	SDAT1_DIR		TRISB, 5
	#define	SINT			PORTB, 0
	#define SINT_DIR		TRISB, 0

	#define	FULL_CARD		PORTC, 2
	#define	FULL_CARD_DIR 	TRISC, 2

	#define BOTTOMY			NUM_ROWS+8		; bottom y vis
	#define	RIGHTX			NUM_COLS+8		; right x vis

	#define	CARRY			STATUS,0
	#define	ZERO			STATUS,2
	#define	NEGATIVE		STATUS,4


	code

pushfsr	macro	
		movff	FSR2H,sFSR0H
		movff	FSR2L,sFSR0L
		endm

popfsr	macro	
		movff	sFSR0H,FSR2H	
		movff	sFSR0L,FSR2L
		endm


;*****************************************************************************
; Pixos Init
;
;
;******************************************************************************

PixosInit
		pushfsr  ;use these macros when switching between c and asm to save fsr registers

		movlb	BANKVARS
	
		clrf	PORTD		
		clrf	LATD
		clrf	TRISD
		setf	TRISE				    ; needed as new board spec RB0 shares with re1?

		bsf		BLANK
	
		bsf		INTCON, GIE		; global interrupts on
		movlw	0xc4
		movwf	T0CON			; system clock 128 prescaler 8 bit counter ( so 256*128 instructions interrupt)
		bsf		INTCON2,TMR0IP	; make tmr0 interrupt high priorit	
		bsf		INTCON,TMR0IE	; enable timer overflow interrupt
		popfsr

		return	

;**************************************************************
; dumpscreen
; description: output screen to multiplex led display
;******************************************************************************

ClockInPixel MACRO pbit
		bsf		SIN
		btfss	INDF0,pbit		
		bcf		SIN
		bsf		SCLK
		nop
		nop
		bcf		SCLK
		endm

ClockInLastPixel MACRO pbit
		bsf		SIN
		btfss	POSTINC0,0		
		bcf		SIN
		bsf		SCLK
		nop
		nop
		bcf		SCLK
		endm

;
;
;
NewLine
		movlb	BANKVARS
		movff	FSR0L,Int2FSR0L
		movff	FSR0H,Int2FSR0H

		incf	RowCtr2
		movlw	0x0f
		andwf	RowCtr2

		movf	RowCtr2,w			
		addwf	WREG,w
		addwf	WREG,w
		movwf	FSR0L
		movlw	high SCREENMEM
		movwf	FSR0H
	
; bit 0-7
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0
; bit 8-15
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0
; bit 16-23
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0
; bit 24-31
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0

		btfss	FULL_CARD				; full or half board
		goto	newlo

		movlw	60
		addwf	FSR0L,f					; move ptr to bottom half

; bit 32-39
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0
; bit 40-47
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0
; bit 48-55
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0
; bit 56-63
		ClockInPixel 7
		ClockInPixel 6
		ClockInPixel 5
		ClockInPixel 4
		ClockInPixel 3
		ClockInPixel 2
		ClockInPixel 1
		ClockInLastPixel 0

newlo	bsf		BLANK			; disable LED display

		bsf		LATCH			; latch the shift regs
		nop
		nop
		bcf		LATCH

		; ALTERNATE method to allow flex assignment of pins etc ( and hide any wiring error )
		bcf		DSEL
		btfss	RowCtr2,3		
		bsf		DSEL
		bcf		CSEL0
		btfss	RowCtr2,0		
		bsf		CSEL0
		bcf		CSEL1
		btfss	RowCtr2,1		
		bsf		CSEL1
		bcf		CSEL2
		btfss	RowCtr2,2		
		bsf		CSEL2

		movff	Int2FSR0L,FSR0L
		movff	Int2FSR0H,FSR0H

		return

	end

